// 
//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010,
//   2011 Free Software Foundation, Inc
// 
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

// Implementation for ActionScript String object.

#ifndef GNASH_STRING_H
#define GNASH_STRING_H

#include <string>
#include "Relay.h"

namespace gnash {

class as_object;
struct ObjectURI;
class Global_as;

class String_as : public Relay
{

public:

    explicit String_as(const std::string& s);

    const std::string& value() {
        return _string;
    }

private:
    std::string _string;
};

/// Initialize the global String class
void string_class_init(as_object& global, const ObjectURI& uri);

void registerStringNative(as_object& global);

}

#endif // GNASH_STRING_H
